// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.


using System;
using System.Runtime.InteropServices;
using System.Runtime.CompilerServices;
using System.Text;
using Silk.NET.Core;
using Silk.NET.Core.Native;
using Silk.NET.Core.Attributes;
using Silk.NET.Core.Contexts;
using Silk.NET.Core.Loader;

#pragma warning disable 1591

namespace Silk.NET.Direct3D11
{
    [StructLayout(LayoutKind.Explicit)]
    [NativeName("Name", "__AnonymousRecord_d3d11_3_L928_C5")]
    public unsafe partial struct ShaderResourceViewDesc1Union
    {
        public ShaderResourceViewDesc1Union
        (
            BufferSrv? buffer = null,
            Tex1DSrv? texture1D = null,
            Tex1DArraySrv? texture1DArray = null,
            Tex2DSrv1? texture2D = null,
            Tex2DArraySrv1? texture2DArray = null,
            Tex2DmsSrv? texture2DMS = null,
            Tex2DmsArraySrv? texture2DMSArray = null,
            Tex3DSrv? texture3D = null,
            TexcubeSrv? textureCube = null,
            TexcubeArraySrv? textureCubeArray = null,
            BufferexSrv? bufferEx = null
        ) : this()
        {
            if (buffer is not null)
            {
                Buffer = buffer.Value;
            }

            if (texture1D is not null)
            {
                Texture1D = texture1D.Value;
            }

            if (texture1DArray is not null)
            {
                Texture1DArray = texture1DArray.Value;
            }

            if (texture2D is not null)
            {
                Texture2D = texture2D.Value;
            }

            if (texture2DArray is not null)
            {
                Texture2DArray = texture2DArray.Value;
            }

            if (texture2DMS is not null)
            {
                Texture2DMS = texture2DMS.Value;
            }

            if (texture2DMSArray is not null)
            {
                Texture2DMSArray = texture2DMSArray.Value;
            }

            if (texture3D is not null)
            {
                Texture3D = texture3D.Value;
            }

            if (textureCube is not null)
            {
                TextureCube = textureCube.Value;
            }

            if (textureCubeArray is not null)
            {
                TextureCubeArray = textureCubeArray.Value;
            }

            if (bufferEx is not null)
            {
                BufferEx = bufferEx.Value;
            }
        }


        [FieldOffset(0)]
        [NativeName("Type", "D3D11_BUFFER_SRV")]
        [NativeName("Type.Name", "D3D11_BUFFER_SRV")]
        [NativeName("Name", "Buffer")]
        public BufferSrv Buffer;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEX1D_SRV")]
        [NativeName("Type.Name", "D3D11_TEX1D_SRV")]
        [NativeName("Name", "Texture1D")]
        public Tex1DSrv Texture1D;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEX1D_ARRAY_SRV")]
        [NativeName("Type.Name", "D3D11_TEX1D_ARRAY_SRV")]
        [NativeName("Name", "Texture1DArray")]
        public Tex1DArraySrv Texture1DArray;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEX2D_SRV1")]
        [NativeName("Type.Name", "D3D11_TEX2D_SRV1")]
        [NativeName("Name", "Texture2D")]
        public Tex2DSrv1 Texture2D;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEX2D_ARRAY_SRV1")]
        [NativeName("Type.Name", "D3D11_TEX2D_ARRAY_SRV1")]
        [NativeName("Name", "Texture2DArray")]
        public Tex2DArraySrv1 Texture2DArray;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEX2DMS_SRV")]
        [NativeName("Type.Name", "D3D11_TEX2DMS_SRV")]
        [NativeName("Name", "Texture2DMS")]
        public Tex2DmsSrv Texture2DMS;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEX2DMS_ARRAY_SRV")]
        [NativeName("Type.Name", "D3D11_TEX2DMS_ARRAY_SRV")]
        [NativeName("Name", "Texture2DMSArray")]
        public Tex2DmsArraySrv Texture2DMSArray;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEX3D_SRV")]
        [NativeName("Type.Name", "D3D11_TEX3D_SRV")]
        [NativeName("Name", "Texture3D")]
        public Tex3DSrv Texture3D;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEXCUBE_SRV")]
        [NativeName("Type.Name", "D3D11_TEXCUBE_SRV")]
        [NativeName("Name", "TextureCube")]
        public TexcubeSrv TextureCube;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_TEXCUBE_ARRAY_SRV")]
        [NativeName("Type.Name", "D3D11_TEXCUBE_ARRAY_SRV")]
        [NativeName("Name", "TextureCubeArray")]
        public TexcubeArraySrv TextureCubeArray;

        [FieldOffset(0)]
        [NativeName("Type", "D3D11_BUFFEREX_SRV")]
        [NativeName("Type.Name", "D3D11_BUFFEREX_SRV")]
        [NativeName("Name", "BufferEx")]
        public BufferexSrv BufferEx;
    }
}
