// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.


using System;
using System.Runtime.InteropServices;
using System.Runtime.CompilerServices;
using System.Text;
using Silk.NET.Core;
using Silk.NET.Core.Native;
using Silk.NET.Core.Attributes;
using Silk.NET.Core.Contexts;
using Silk.NET.Core.Loader;

#pragma warning disable 1591

namespace Silk.NET.Vulkan
{
    [NativeName("Name", "VkDescriptorSetAllocateInfo")]
    public unsafe partial struct DescriptorSetAllocateInfo
    {
        public DescriptorSetAllocateInfo
        (
            StructureType? sType = StructureType.DescriptorSetAllocateInfo,
            void* pNext = null,
            DescriptorPool? descriptorPool = null,
            uint? descriptorSetCount = null,
            DescriptorSetLayout* pSetLayouts = null
        ) : this()
        {
            if (sType is not null)
            {
                SType = sType.Value;
            }

            if (pNext is not null)
            {
                PNext = pNext;
            }

            if (descriptorPool is not null)
            {
                DescriptorPool = descriptorPool.Value;
            }

            if (descriptorSetCount is not null)
            {
                DescriptorSetCount = descriptorSetCount.Value;
            }

            if (pSetLayouts is not null)
            {
                PSetLayouts = pSetLayouts;
            }
        }

/// <summary></summary>
        [NativeName("Type", "VkStructureType")]
        [NativeName("Type.Name", "VkStructureType")]
        [NativeName("Name", "sType")]
        public StructureType SType;
/// <summary></summary>
        [NativeName("Type", "void*")]
        [NativeName("Type.Name", "void")]
        [NativeName("Name", "pNext")]
        public void* PNext;
/// <summary></summary>
        [NativeName("Type", "VkDescriptorPool")]
        [NativeName("Type.Name", "VkDescriptorPool")]
        [NativeName("Name", "descriptorPool")]
        public DescriptorPool DescriptorPool;
/// <summary></summary>
        [NativeName("Type", "uint32_t")]
        [NativeName("Type.Name", "uint32_t")]
        [NativeName("Name", "descriptorSetCount")]
        public uint DescriptorSetCount;
/// <summary></summary>
        [NativeName("Type", "VkDescriptorSetLayout*")]
        [NativeName("Type.Name", "VkDescriptorSetLayout")]
        [NativeName("Name", "pSetLayouts")]
        public DescriptorSetLayout* PSetLayouts;
    }
}
